package de.hawhamburg.reachability.sensor.adapter.json;

import de.hawhamburg.lifecycle.data.JsonLPObject;

/**
 * A JSON message which is part of the UbiSence Messaging System and provides informations on the inhabitants current 
 * position.<br><br>
 * 
 * compare: http://livingplace.informatik.haw-hamburg.de/wiki/index.php/ActiveMQ_Messages#Tracking.
 * <br><br>
 * 
 * <code>[2013-03-15] Slightly modified by Malte Kantak for CheckStyle compatibility</code><br>
 * <code>[2013-03-15] JavaDocs added by Malte Kantak</code>
 * 
 * @author Jens Ellenberg
 */
public class JsonPosition extends JsonLPObject {
    /**
     * X-position of the Ubisense tag.
     */
    public double X;
    
    /**
     * Y-position of the Ubisense tag.
     */
    public double Y;
    
    /**
     * Z-position of the Ubisense tag.
     */
    public double Z;
    
    /**
     * Public constructor will set the internal coordinates of the class instance.
     * 
     * @param x     The x-position of the Ubisense tag.
     * @param y     The y-position of the Ubisense tag.
     * @param z     The z-position of the Ubisense tag.
     */
    public JsonPosition(final double x,
                        final double y,
                        final double z) {
        this.X = x;
        this.Y = y;
        this.Z = z;
    }
    
    /**
     * Public default constructor without class field initialization.
     */
    public JsonPosition() { }
    
    /**
     * Generates and returns the {@link String} representation of this JSON object.
     * 
     * @return      The {@link String} representation of this JSON object.
     */
    @Override
    public final String toString() {
        return "X: " + X + " Y: " + Y + " Z: " + Z;
    }
}
