package de.hawhamburg.reachability.sensor.adapter.json;

import de.hawhamburg.lifecycle.data.JsonLPObject;

/**
 * A JSON message which is part of the UbiSence Messaging System and will provide informations on the inhabitants 
 * current position.<br><br>
 * 
 * compare: http://livingplace.informatik.haw-hamburg.de/wiki/index.php/ActiveMQ_Messages#Tracking.
 * <br><br>
 * 
 * <code>[2013-03-15] Slightly modified by Malte Kantak for CheckStyle compatibility</code><br>
 * <code>[2013-03-15] JavaDocs added by Malte Kantak</code>
 * 
 * @author Jens Ellenberg
 */
public class JsonUbiSenseMessage extends JsonLPObject {
    
    /**
     * The UbiSense tag ID.
     */
    public String UbisenseTagId;
    
    /**
     * The measuring unit of the position values.
     */
    public String Unit;
    
    /**
     * The new position of the tag.
     */
    public JsonPosition NewPosition;
    
    /**
     * Default public constructor to create instances of this class.
     */
    public JsonUbiSenseMessage() { }
    
    /**
     * Generates an returns the {@link String} representation of this object.
     * 
     * @return  The {@link String} representation of this object.
     */
    @Override
    public final String toString() {
        return UbisenseTagId + " an der Position: " + NewPosition;
    }
}
